class puppet_enterprise::mcollective::server::facter {
  include puppet_enterprise::params
  $mco_etc = $puppet_enterprise::params::mco_etc

  File {
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0775',
  }

  # make sure the < PE3 custom facts file for this module is removed
  file { "${puppet_enterprise::params::facter_etc}/facts.d/puppet_enterprise_installer.txt" :
    ensure => absent,
  }

  # Manage facter metadata updates for MCollective in PE.
  if $::osfamily == 'windows' {
    file { 'refresh-mcollective-metadata.bat':
      path    => "${mco_etc}/refresh-mcollective-metadata.bat",
      content => template('puppet_enterprise/mcollective/refresh-mcollective-metadata.bat.erb'),
      before  => [ Exec['bootstrap mcollective metadata'], Scheduled_task['pe-mcollective-metadata'] ],
    }
    file { 'refresh-mcollective-metadata.rb':
      path    => "${mco_etc}/refresh-mcollective-metadata.rb",
      content => template('puppet_enterprise/mcollective/refresh-mcollective-metadata.erb'),
      before  => [ Exec['bootstrap mcollective metadata'], Scheduled_task['pe-mcollective-metadata'] ],
    }
    exec { 'bootstrap mcollective metadata':
      command => "\"${mco_etc}/refresh-mcollective-metadata.bat\"",
      creates => "${mco_etc}/facts.yaml",
      before  => Service['pe-mcollective'],
    }
    scheduled_task { 'pe-mcollective-metadata':
      ensure  => 'present',
      command => "${mco_etc}/refresh-mcollective-metadata.bat",
      enabled => true,
      trigger => {
        'every'      => '1',
        'schedule'   => 'daily',
        'start_time' => '13:00'
      },
    }
  }
  else {
    file { '/opt/puppet/sbin/refresh-mcollective-metadata':
      content => template('puppet_enterprise/mcollective/refresh-mcollective-metadata.erb'),
      before  => Cron['pe-mcollective-metadata'],
    }
    cron { 'pe-mcollective-metadata':
      command => '/opt/puppet/sbin/refresh-mcollective-metadata',
      user    => $puppet_enterprise::params::root_user,
      minute  => [ '0', '15', '30', '45' ],
    }
  }
}
