# == Class: puppet_enterprise::profile::mcollective::console
#
# Profile for creating the console mcollective user && client. This is a special user that lives on
# the console node and is intended for issuing orchestration commands via the live management page.
#
# === Parameters
#
# [*create_user*]
#   Whether or not we should create and manage this users account on disk.
#
# [*home_dir*]
#   The home directory of the peadmin system user. Defaults to `/var/lib/peadmin`.
#
# [*stomp_passowrd*]
#   The stomp password. But default this is read from disk.
#
# [*stomp_port*]
#   The port that the stomp service is listening on
#
# [*stomp_user*]
#   The username for sending messages over the stomp protocol.
#
class puppet_enterprise::profile::mcollective::console(
  $activemq_brokers       = $puppet_enterprise::mcollective_middleware_hosts,
  $create_user            = $puppet_enterprise::params::mco_create_client_user,
  $home_dir               = '/opt/puppet/share/puppet-dashboard',
  $stomp_password         = $puppet_enterprise::mcollective_middleware_password,
  $stomp_port             = $puppet_enterprise::mcollective_middleware_port,
  $stomp_user             = $puppet_enterprise::mcollective_middleware_user,
) inherits puppet_enterprise {

  puppet_enterprise::mcollective::client { 'puppet-dashboard':
    activemq_brokers => $activemq_brokers,
    cert_name        => $puppet_enterprise::params::mco_console_client_name,
    keypair_name     => $puppet_enterprise::params::mco_console_keypair_name,
    create_user      => $create_user,
    home_dir         => $home_dir,
    logfile          => '/var/log/pe-puppet-dashboard/mcollective_client.log',
    stomp_password   => $stomp_password,
    stomp_port       => $stomp_port,
    stomp_user       => $stomp_user,
  }

  # The home directory must be world-readable for the Dashboard to work
  # in Apache. This resource is declared in the accounts::user defined
  # type.
  File <| title == $home_dir |> {
    mode => '0755',
  }
}
