class puppet_enterprise::puppetdb::jetty_ini(
  $certname,
  $cert_whitelist_path = $puppet_enterprise::params::puppetdb_cert_whitelist_path,
  $confdir             = $puppet_enterprise::params::puppetdb_confdir,
  $listen_address      = $puppet_enterprise::params::plaintext_address,
  $listen_port         = $puppet_enterprise::params::puppetdb_listen_port,
  $localcacert         = $puppet_enterprise::params::localcacert,
  $ssl_dir             = $puppet_enterprise::params::puppetdb_ssl_dir,
  $ssl_listen_address  = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port     = $puppet_enterprise::params::puppetdb_ssl_listen_port,
) inherits puppet_enterprise::params {

  file { "${confdir}/jetty.ini":
    ensure => present,
    owner  => 'pe-puppetdb',
    group  => 'pe-puppetdb',
    mode   => '0640',
  }

  #Set the defaults
  Pe_ini_setting {
    ensure  => present,
    path    => "${confdir}/jetty.ini",
    section => 'jetty',
  }

  if pe_empty($listen_port) {
    pe_ini_setting {'puppetdb_host':
      ensure  => absent,
      setting => 'host',
    }
    pe_ini_setting {'puppetdb_port':
      ensure  => absent,
      setting => 'port',
    }
  } else {
    pe_ini_setting {'puppetdb_host':
      setting => 'host',
      value   => $listen_address,
    }

    pe_ini_setting {'puppetdb_port':
      setting => 'port',
      value   => $listen_port,
    }
  }

  pe_ini_setting {'puppetdb_sslhost':
    setting => 'ssl-host',
    value   => $ssl_listen_address,
  }

  pe_ini_setting {'puppetdb_sslport':
    setting => 'ssl-port',
    value   => $ssl_listen_port,
  }

  pe_ini_setting {'puppetdb_ssl_key':
    setting => 'ssl-key',
    value   => "${ssl_dir}/${certname}.private_key.pem",
  }

  pe_ini_setting {'puppetdb_ssl_cert':
    setting => 'ssl-cert',
    value   => "${ssl_dir}/${certname}.cert.pem",
  }

  pe_ini_setting {'puppetdb_ssl_ca_cert':
    setting => 'ssl-ca-cert',
    value   => $localcacert,
  }

  pe_ini_setting { 'puppetdb-certificate-whitelist':
    setting => 'certificate-whitelist',
    value   => $cert_whitelist_path,
    require => File[$cert_whitelist_path],
  }
}
