require 'spec_helper'

describe 'puppet_enterprise::master::puppetserver' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'master.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
      'processorcount'    => '1',
    }

    @params = {
      'certname'       => 'master.rspec',
      'metrics_enabled' => true,
      'metrics_server_id' => 'localhost',
      'metrics_jmx_enabled' => true,
      'metrics_graphite_enabled' => false,
      'metrics_graphite_host' => 'graphite',
      'metrics_graphite_port' => 2003,
      'metrics_graphite_update_interval_seconds' => 30,
      'profiler_enabled' => true
    }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:confdir) { "/etc/puppetlabs/puppetserver" }
  let(:logpath) { "/var/log/pe-puppetserver/puppetserver.log" }

  context "managing files" do
    it { should contain_pe_concat("#{confdir}/bootstrap.cfg").with_mode('0640') }
    it { should contain_file("#{confdir}/logback.xml").with_mode('0640') }
    it { should contain_file("#{confdir}/conf.d/webserver.conf").with_mode('0640') }
    it { should contain_file("#{confdir}/conf.d/webserver.conf").with_content(%r[ssl-ca-cert\s*:\s*/etc/puppetlabs/puppet/ssl/certs/ca.pem]) }
    it { should contain_file("#{confdir}/conf.d/webserver.conf").with_content(%r[ssl-crl-path\s*:\s*/etc/puppetlabs/puppet/ssl/crl.pem]) }
    it { should contain_file("#{confdir}/conf.d/global.conf").with_mode('0640') }
    it { should contain_file("#{confdir}/conf.d/pe-puppet-server.conf").with_mode('0640') }
    it { should contain_file("#{confdir}/conf.d/metrics.conf").with_mode('0640') }
  end


  context "serving static files" do
    before :each do
      @params['static_files'] = {"/baz-files" => "/foo/bar/baz",
                                 "/others" => "/foo/bar/others"}
    end
    it { should contain_file("#{confdir}/conf.d/webserver.conf").with_content %r[resource: "/foo/bar/baz", path: "/baz-files", follow-links: true] }
    it { should contain_file("#{confdir}/conf.d/webserver.conf").with_content %r[resource: "/foo/bar/others", path: "/others", follow-links: true] }
  end

  context "managing services" do
    it { should contain_service('pe-puppetserver').with_ensure('running') }
  end
end

